<?php

declare(strict_types=1);

namespace Payshop\Core\Block;

use Magento\Checkout\Model\Session;
use Magento\Framework\View\Asset\Repository;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;

class PaymentInformations extends Template
{
    /**
     * @var Session
     */
    private Session $session;

    /**
     * @var Repository
     */
    protected $_assetRepo;

    /**
     * PaymentInformations constructor.
     * 
     * @param Context $context 
     * @param Session $session 
     * @param Repository $assetRepo 
     */
    public function __construct(
        Context $context,
        Session $session,
        Repository $assetRepo
    ) {
        parent::__construct($context);
        $this->session = $session;
        $this->_assetRepo = $assetRepo;
    }

    /**
     * Return payment additional informations
     *
     * @return array
     */
    public function getPaymentAdditionalInformation(): array
    {
        $isNotPayshopReference = $this->getPaymentMethodName() !== 'payshop_payshop_reference';
        $isNotMultibancoReference = $this->getPaymentMethodName() !== 'payshop_multibanco_reference';

        if ($isNotPayshopReference && $isNotMultibancoReference) {
            return [];
        }

        return $this->session->getLastRealOrder()->getPayment()->getAdditionalInformation();
    }

    /**
     * Return payment method name
     *
     * @return string
     */
    public function getPaymentMethodName(): string
    {
        $order = $this->session->getLastRealOrder();
        $payment = $order->getPayment();

        return $payment->getMethod();
    }


    /**
     * Return order ID
     *
     * @return string
     */
    public function getOrderId(): string
    {
        $order = $this->session->getLastRealOrder();
        
        return $order->getId();
    }

    /**
     * Return payment method image
     *
     * @param string $imagemName
     * @return string
     */
    public function getImageUrl(string $imagemName): string
    {
        return $this->_assetRepo->getUrl("Payshop_Core::img/$imagemName");
    }
}
