<?php

namespace Payshop\Core\Block;

use Magento\Sales\Api\Data\OrderInterface;
use Magento\Sales\Api\OrderRepositoryInterface;
use Magento\Framework\View\Element\Template\Context;

class PaymentReferences extends \Magento\Framework\View\Element\Template
{
    /**
     * @var OrderRepositoryInterface
     */
    private OrderRepositoryInterface $orderRepository;

    /**
     * @param Context $context
     * @param array $data
     * @param OrderRepositoryInterface $orderRepository
     */
    public function __construct(
        Context $context,
        OrderRepositoryInterface $orderRepository
    ) {
        parent::__construct($context);
        $this->orderRepository = $orderRepository;
    }

    /**
     * Return payment additional informations
     *
     * @return array
     */
    public function getPaymentAdditionalInformation(): array
    {
        return $this->getOrder()->getPayment()->getAdditionalInformation();
    }

    /**
     * Return payment method name
     *
     * @return string
     */
    public function getPaymentMethodName(): string
    {
        $order = $this->getOrder();
        $payment = $order->getPayment();

        return $payment->getMethod();
    }

    /**
     * Return order
     *
     * @return OrderInterface|null
     */
    public function getOrder(): ?OrderInterface
    {
        $order = $this->getData('order');

        if ($order !== null) {
            return $order;
        }
        $orderId = (int)$this->getData('order_id');

        if ($orderId) {
            $order = $this->orderRepository->get($orderId);

            $this->setData('order', $order);
        }

        return $order;
    }
}
