<?php

namespace Payshop\Core\Gateway\Authorize\Http\Client;

use Magento\Payment\Gateway\Http\ClientInterface;
use Magento\Payment\Gateway\Http\TransferInterface;
use Payshop\Core\Gateway\SDK\PayshopSDKClientFactory;

class PayshopTransaction implements ClientInterface
{
    /**
     * @var PayshopSDKClientFactory
     */
    private PayshopSDKClientFactory $payshopSDKClientFactory;

    /**
     * PayshopTransaction Constructor.
     * 
     * @param PayshopSDKClientFactory $payshopSDKClientFactory
     */
    public function __construct(
        PayshopSDKClientFactory $payshopSDKClientFactory
    ) {
        $this->payshopSDKClientFactory = $payshopSDKClientFactory;
    }

    /**
     * @inheritDoc
     */
    public function placeRequest(TransferInterface $transferObject)
    {
        $payshopClient = $this->payshopSDKClientFactory->getInstance();
        $requestData = $transferObject->getBody();

        try {
            $response = $payshopClient->getInstrument($requestData['instrumentId']);

            $this->checkResponse($response);
            $instrument = $response['response'];
            
            $this->checkPayment($instrument);

            return [
                'status' => 'ok',
                'instrument' => $instrument
            ];
        } catch (\Throwable $th) {
            return [
                'status' => 'error',
                'code' => $th->getMessage()
            ];
        }
    }

    /**
     * Check Payshop response
     *
     * @param array $response
     * @return void
     * @throws Exception
     */
    private function checkResponse(array $response): void
    {
        if ($response['status'] != 200) {
            throw new \Exception('400002');
        }
    }

    /**
     * Get order status from the instrument response
     *
     * @param array $instrument
     * @return void
     * @throws Exception
     */
    private function checkPayment(array $instrument): void
    {
        $paymentInTwoSteps = $instrument['capture_on_creation'] == false;
        $instrumentSuccessCreated = $instrument['success'] == true;
        $authorizedPayment = $instrument['status'] == 'authorized';

        if ($paymentInTwoSteps && $instrumentSuccessCreated && $authorizedPayment) {
            return;
        }

        $issetPayment = isset($instrument['last_payment']);
        $paymentSucess = $issetPayment && $instrument['last_payment']['success'];
        $paymentStatusSucess = $issetPayment && $instrument['last_payment']['status'] == 'success';

        if ($paymentSucess && $paymentStatusSucess) {
            return;
        }

        throw new \Exception('200001');
    }
}
