<?php

namespace Payshop\Core\Gateway\Initialize\Request;

use Payshop\Core\Action\CreateCharge;
use Magento\Payment\Gateway\Request\BuilderInterface;
use Magento\Payment\Gateway\Data\PaymentDataObjectInterface;

class ChargeRequest implements BuilderInterface
{
    /**
     * @var CreateCharge
     */
    private CreateCharge $createCharge;

    /**
     * ChargeRequest constructor.
     * 
     * @param CreateCharge $createCharge
     */
    public function __construct(
        CreateCharge $createCharge
    ) {
        $this->createCharge = $createCharge;
    }

    /**
     * Build charge request
     * 
     * @param array $buildSubject
     * @return array
     */
    public function build(array $buildSubject)
    {
        if (!isset($buildSubject['payment'])
            || !$buildSubject['payment'] instanceof PaymentDataObjectInterface
        ) {
            throw new \InvalidArgumentException('Payment data object should be provided');
        }

        $paymentDataObject = $buildSubject['payment'];
        $order = $paymentDataObject->getOrder();
        $payment = $paymentDataObject->getPayment();

        return [
            'charge' => $this->createCharge->getData($order, $payment->getMethod())
        ];
    }
}
