<?php

namespace Payshop\Core\Model\Message;

use Magento\Framework\Module\ResourceInterface;
use Magento\Framework\Notification\MessageInterface;

class UpdateAlert implements MessageInterface
{
    /**
     * @var string
     */
    const ONLINE_VERSION_URL = 'https://apps.coolsis.pt/payshop/magento/version.json';

    /**
     * @var ResourceInterface $moduleResource
     */
    protected ResourceInterface $_moduleResource;

    /**
     * @var array
     */
    private array $onlineVersionInformations;

    /**
     * UpdateAlert constructor.
     *
     * @param ResourceInterface $moduleResource
     */
    public function __construct(
        ResourceInterface $moduleResource
    ) {
        $this->_moduleResource = $moduleResource;
        $this->onlineVersionInformations = $this->getOnlineVersion();
    }
    
    /**
     * Retrieve unique message identity
     *
     * @return string
     */
    public function getIdentity(): string
    {
        return 'payshop_core_update_alert';
    }

    /**
     * Check if message should be displayed
     *
     * @return bool
     */
    public function isDisplayed(): bool
    {
        return ! $this->isUpdated();
    }

    /**
     * Retrieve message text
     *
     * @return string
     */
    public function getText(): string
    {
        $alert = __('A new version of the Payshop module is available');
        $download = __('You can download the latest version from here:');

        $link = sprintf(
            '<a href="%s" target="_blank">' . __('download') . '</a>',
            $this->onlineVersionInformations['url']
        );

        return vsprintf(
            '%s. %s %s',
            [
                $alert,
                $download,
                $link
            ]
        );
    }
    
    /**
     * Retrieve message severity
     *
     * @return int
     */
    public function getSeverity(): int
    {
        return self::SEVERITY_CRITICAL;
    }

    /**
     * Get version from online URL
     *
     * @return array
     */
    private function getOnlineVersion(): array
    {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_URL, self::ONLINE_VERSION_URL);
        $data = curl_exec($ch);
        curl_close($ch);
        $current_version = $data;

        $versionInformation = json_decode($current_version, true);

        return $versionInformation;
    }

    /**
     * Check if the module is updated
     *
     * @return bool
     */
    private function isUpdated(): bool
    {
        $moduleVersion = $this->_moduleResource->getDbVersion('Payshop_Core');

        return version_compare(
            $moduleVersion,
            $this->onlineVersionInformations['version'],
            '=='
        );
    }
}

function dd(...$args)
{
    foreach ($args as $arg) {
        var_dump($arg);
    }
    die();
}



