<?php

namespace Payshop\Core\Validation;

use DateTime;
use Magento\Sales\Api\Data\OrderInterface;

class ConfirmCardPayment
{
    /**
     * Check if order is a card order
     * 
     * @param OrderInterface $order
     * @return bool
     */
    public static function isCard(OrderInterface $order): bool
    {
        return $order->getPayment()->getMethod() === 'payshop_card';
    }

    /**
     * Check if order is in processing status
     * 
     * @param OrderInterface $order
     * @return bool
     */
    public static function isProcessingStatus(OrderInterface $order): bool
    {
        return $order->getStatus() === 'processing';
    }

    /**
     * Check if order is in two steps payment
     * 
     * @param OrderInterface $order
     * @return bool
     */
    public static function isPaymentInTwoSteps(OrderInterface $order): bool
    {
        $payment = $order->getPayment();

        return $payment->getAdditionalInformation('payment_in_two_steps') == 'Sim';
    }

    /**
     * Check if order efective value is confirmed
     * 
     * @param OrderInterface $order
     * @return bool
     */
    public static function isPaymentConfirmed(OrderInterface $order): bool
    {
        $payment = $order->getPayment();

        return $payment->getAdditionalInformation('confirmation_date') != null;
    }

    /**
     * Get de limit date to confirm payment
     * 
     * @param OrderInterface $order
     * @return DateTime
     */
    public static function getDateLimitToConfirmPayment(OrderInterface $order): DateTime
    {
        $createOrderDate = $order->getCreatedAt();

        $limiteToConfirmPayment = new DateTime($createOrderDate);

        $daystoConfirmPayment = 'P7D';
        $limiteToConfirmPayment->add(new \DateInterval($daystoConfirmPayment));

        return $limiteToConfirmPayment;
    }

    /**
     * Check if date limit to confirm payment is expired
     * 
     * @param OrderInterface $order
     * @return bool
     */
    public static function isDateLimitToConfirmPaymentExpired(OrderInterface $order): bool
    {
        $dateLimitToConfirmPayment = self::getDateLimitToConfirmPayment($order);
        $currentDate = new DateTime();

        return $currentDate > $dateLimitToConfirmPayment;
    }
}