/*browser:true*/
/*global define*/
define([
    'jquery',
    'mage/url',
    'Magento_Payment/js/view/payment/cc-form',
    'Magento_Payment/js/model/credit-card-validation/validator'
], function ($, url, Component) {
    'use strict';

    return Component.extend({
        defaults: {
            template: 'Payshop_Core/payment/card',
            code: 'payshop_card',
            creditCardHolderName: ''
        },

        /**
         * @returns {exports.initObservable}
         */
        initObservable: function () {
            this._super()
                .observe([
                    'creditCardHolderName'
                ]);
            return this;
        },

        /**
         * @returns {String}
         */
        getCode: function () {
            return this.code;
        },

        /**
         * @returns {Boolean}
         */
        isActive: function () {
            return this.getCode() === this.isChecked();
        },

        /**
         * @returns {void}
         */
        placeOrder: function (data, event) {
            $('.loading-mask').show();

            if (event) {
                event.preventDefault();
            }

            var self = this;
            
            if (this.validate()) {
                let number = this.creditCardNumber();
                let name = this.creditCardHolderName();
                let expiration_month = this.creditCardExpMonth();
                let expiration_year = this.creditCardExpYear();
                let cvc = this.creditCardVerificationNumber();

                let cardInitializeUrl = url.build('payshop/card/initialize');

                $.ajax({
                    url: cardInitializeUrl,
                    type: 'POST',
                    data: {
                        number,
                        name,
                        expiration_month,
                        expiration_year,
                        cvc
                    },
                    success: function (data) {
                        window.location.href = data.url;
                        console.log(data);
                    },
                    error: function (error) {
                        let message;

                        if (error?.responseJSON?.message != null) {
                            message = error.responseJSON.message;
                        } else {
                            message = 'Error to create payment';
                        }

                        self.messageContainer.addErrorMessage({message});
                        $('.loading-mask').hide();
                    }
                });
            } else {
                $('.loading-mask').hide();
            }
        },

        /**
         * @returns {*|jQuery|(function(): void)}
         */
        validate: function () {
            var form = $(this.getSelector('payment-form'));

            form.validation({ focusInvalid: false });
            $('form').off('invalid-form.validate');

            return form.valid();
        },

        /**
         * @param {String} field
         * @returns {String}
         */
        getSelector: function (field) {
            return '#' + this.getCode() + '_' + field;
        },
    });
});